@@ -1,6 +1,7 @@
 from .client import Client
 from .models import UserData, PurchaseData, AdData, RetentionData
-from .api import AppEvent, RegisterUser, FetchToken
+from .api import AppEvent, RegisterUser, FetchToken, UpdateCumulativeValues
+from .sdk_version import SDKVersion
 
 __all__ = [
     "Client",
@@ -11,4 +12,6 @@ __all__ = [
     "AppEvent",
     "RegisterUser",
     "FetchToken",
+    "UpdateCumulativeValues",
+    "SDKVersion",
 ] 
\ No newline at end of file
