@@ -1,9 +1,11 @@
 from .register_user import RegisterUser
 from .app_event import AppEvent
 from .fetch_token import FetchToken
+from .update_cumulative_values import UpdateCumulativeValues
 
 __all__ = [
     "RegisterUser",
     "AppEvent",
     "FetchToken",
+    "UpdateCumulativeValues",
 ] 
\ No newline at end of file
