@@ -21,5 +21,5 @@ class RetentionData:
                 return {"status": False, "message": f"{field} is missing"}
         return {"status": True, "message": ""}
 
-    def to_json(self):
+    def to_json(self, user_data=None):
         return self.data 
\ No newline at end of file
