@@ -1,4 +1,5 @@
 from datetime import datetime, timezone, timedelta
+from ..sdk_version import SDKVersion
 
 
 class UserData:
@@ -10,6 +11,7 @@ class UserData:
         self.user_id = None
         self.client_ip_address = None
         self.timestamp = datetime.now(timezone.utc).isoformat()
+        self.app_version = "unknown"
 
     def set_user_id(self, user_id):
         self.user_id = user_id
@@ -18,6 +20,10 @@ class UserData:
     def set_user_ip(self, ip_address):
         self.client_ip_address = ip_address
         return self
+    
+    def set_app_version(self, app_version):
+        self.app_version = app_version
+        return self
 
     def set_last_login(self, last_login):
         try:
@@ -241,6 +247,9 @@ class UserData:
             "device_model": creative_info.get("device_model"),
             "os_system": creative_info.get("os_system"),
             "retention_day": retention.get("retention_day", 0),
+            "sdk_version": SDKVersion.get_version(),
+            "sdk_type": SDKVersion.get_sdk_type(),
+            "app_version": self.app_version,
             "client_ip": self.client_ip_address,
             "timestamp": self.timestamp
         }
@@ -303,4 +312,10 @@ class UserData:
         payload["user_id"] = self.user_id
         payload["ip_address"] = self.client_ip_address
         payload["timestamp"] = self.timestamp
-        return json.dumps(payload)
\ No newline at end of file
+        return json.dumps(payload)
+    
+    def get_sdk_version(self):
+        return SDKVersion.get_version()
+    
+    def get_app_version(self):
+        return self.app_version
\ No newline at end of file
